@@ -1,11 +1,17 @@
 from __future__ import annotations
 
+import sys
 from datetime import datetime
 from enum import Enum
 from time import time
 from typing import Any, Callable, Dict, List, Optional, Type, TypeVar, Union
 from uuid import UUID
 
+if sys.version_info >= (3, 8):
+    from typing import TypedDict
+else:
+    from typing_extensions import TypedDict
+
 from httpx import Response
 from pydantic import BaseModel, root_validator
 
@@ -150,3 +156,12 @@ class LinkType(str, Enum):
     magiclink = "magiclink"
     recovery = "recovery"
     invite = "invite"
+
+
+class UserAttributesDict(TypedDict):
+    """Dict version of `UserAttributes`"""
+
+    email: Optional[str]
+    password: Optional[str]
+    email_change_token: Optional[str]
+    data: Optional[Any]
